;   /**
;    * LoopPointSource is a wrapper around another SampleSource, providing
;    * custom loop behavior.  LoopPointSource maintains a set of links
;    * within the sample stream And whenever the location of one of the links
;    * (i.e. a loop point) is reached, the stream jumps To that link's target.
;    * Each loop point maintains a count.  Every time a loop point comes into
;    * effect, the count is decremented.  Once it reaches zero, that loop point
;    * is temporarily disabled.  If a count is not a positive value, it
;    * cannot be disabled.  calling reset() resets all counts To their initial
;    * values.
;    *
;    * loop points only take effect When repeating has been enabled via the
;    * setRepeat() method.
;    *
;    * loop points are stored in sorted order by their location.  Each one
;    * has an index based on its location within the list.  a loop point's
;    * index will change If another is added before it.
;    *
;    * There is always one implicit loop point after the last sample that
;    * points back To the first.  that way, This class's default looping
;    * behavior is the same as a standard SampleSource.  This loop point
;    * does not show up in the list.
;    */Enumeration
Enumeration
  #audiere
EndEnumeration

IncludeFile "audiere.pbi"

If OpenLibrary(#audiere,"audiere.dll")=0
MessageRequester("","Error audiere.dll",0):End:EndIf


                                            ; open a device
AudioDeviceObject.AudioDevice=AUDIERE_OpenDevice(@"winmm",@"buffer=100,rate=44100")    
    If AudioDeviceObject=0
    MessageRequester("","Error AUDIERE_OpenDevice:",0):End:EndIf
    
                                            ; open a sound
SampleSourceObject.SampleSource= AUDIERE_OpenSampleSource(@"machinae_supremacy_-_sidstyler.ogg",#FF_AUTODETECT) 
    If SampleSourceObject=0
    MessageRequester("","Error AUDIERE_OpenSampleSource",0):End:EndIf

                                            ; Create a "loopable" sampleobject
LoopPointSourceObject.LoopPointSource=AUDIERE_CreateLoopPointSource(SampleSourceObject)
    If LoopPointSourceObject=0
    MessageRequester("","Error AUDIERE_CreateLoopPointSource",0):End:EndIf


Debug "You will hear:"
Debug ""
Debug "Repeating five times between 100000 and 50000"
LoopPointSourceObject\addLoopPoint(100000,50000,5)          ; set LoopPoint 1
Debug "Repeating five times between 150000 and 120000 WILL BE NOT PLAYED"
LoopPointSourceObject\addLoopPoint(150000,120000,5)         ; set LoopPoint 2
Debug "Repeating five times between 190000 and 181000"
LoopPointSourceObject\addLoopPoint(190000,181000,5)         ; set LoopPoint 3
Debug ""


; /**
; * Removes the loop point at index 'index' from the stream.
; *
; * @param index  index of the loop point To Remove
; */
LoopPointSourceObject\removeLoopPoint(2)                    ; delete LoopPoint 2


Debug "The amount of looppoints is:"+Str(LoopPointSourceObject\getLoopPointCount())


; Repeat it ? -> yes
LoopPointSourceObject\setRepeat(#True)


; create the output object 
OutputStreamObject.OutputStream=AUDIERE_OpenSound(AudioDeviceObject,LoopPointSourceObject,AUDIERE_FF_AUTODETECT)
OutputStreamObject\play()


MessageRequester("","Press OK to stop this mess",0)


OutputStreamObject\stop()                           ; stop that noise


OutputStreamObject\ref()                            ; refcounter+1
OutputStreamObject\unref()                          ; delete the object (refcounter-1)

AudioDeviceObject\ref()                             ; refcounter+1
AudioDeviceObject\unref()                           ; delete the object (refCounter-1)
                                                    ;
                                                    ; Note:
                                                    ; It isn't necessary to delete the 
                                                    ; SampleSourceObject and the  
                                                    ; LoopPointSourceObject because 
                                                    ; AUDIERE_OpenSound(foo) takes care of it.
                                                    ; Don't ask me why .... :*|
CloseLibrary(#audiere)
; ExecutableFormat=Windows
; CursorPosition=39
; FirstLine=22
; EOF