;   /**
;    * LoopPointSource is a wrapper around another SampleSource, providing
;    * custom loop behavior.  LoopPointSource maintains a set of links
;    * within the sample stream And whenever the location of one of the links
;    * (i.e. a loop point) is reached, the stream jumps To that link's target.
;    * Each loop point maintains a count.  Every time a loop point comes into
;    * effect, the count is decremented.  Once it reaches zero, that loop point
;    * is temporarily disabled.  If a count is not a positive value, it
;    * cannot be disabled.  calling reset() resets all counts To their initial
;    * values.
;    *
;    * loop points only take effect When repeating has been enabled via the
;    * setRepeat() method.
;    *
;    * loop points are stored in sorted order by their location.  Each one
;    * has an index based on its location within the list.  a loop point's
;    * index will change If another is added before it.
;    *
;    * There is always one implicit loop point after the last sample that
;    * points back To the first.  that way, This class's default looping
;    * behavior is the same as a standard SampleSource.  This loop point
;    * does not show up in the list.
;    */
Enumeration
  #audiere
EndEnumeration

IncludeFile "audiere.pbi"

If OpenLibrary(#audiere,"audiere.dll")=0
MessageRequester("","Error audiere.dll",0):End:EndIf


                                            ; open a device
AudioDeviceObject.AudioDevice=AUDIERE_OpenDevice(@"winmm",@"buffer=100,rate=44100")    
    If AudioDeviceObject=0
    MessageRequester("","Error AUDIERE_OpenDevice:",0):End:EndIf
    
                                            ; open a sound
SampleSourceObject.SampleSource= AUDIERE_OpenSampleSource(@"machinae_supremacy_-_sidstyler.ogg",#FF_AUTODETECT) 
    If SampleSourceObject=0
    MessageRequester("","Error AUDIERE_OpenSampleSource",0):End:EndIf


; Create a "loopable" sampleobject
LoopPointSourceObject.LoopPointSource=AUDIERE_CreateLoopPointSource(SampleSourceObject)
    If LoopPointSourceObject=0
    MessageRequester("","Error AUDIERE_CreateLoopPointSource",0):End:EndIf


; and add the LoopPoint
LoopPointSourceObject\addLoopPoint(100000,50000,5)


; /**
; * Sets whether the sample Source should Repeat Or not.  Note that not
; * all sample sources Repeat by starting again at the beginning of the
; * Sound.  For example MOD Files can contain embedded loop points.
; *
; * @param Repeat  true If the Source should Repeat, false otherwise
; */
LoopPointSourceObject\setRepeat(#True)


; create the output object 
OutputStreamObject.OutputStream=AUDIERE_OpenSound(AudioDeviceObject,LoopPointSourceObject,AUDIERE_FF_AUTODETECT)


MessageRequester("READ THIS !","If you press OK the sound will begin to play and when it reaches frame 100000"+Chr(13)+"it will jump back 5 times to frame 50000 and after that it will play normally until the"+Chr(13)+"sound is finished.",0)


; play it
OutputStreamObject\play()


MessageRequester("READ THIS !","When the music isn't looping anymore you can press OK and restart the whole procedure.",0)


; restart the whole mess
OutputStreamObject\reset()


MessageRequester("","Press OK to stop this mess",0)




OutputStreamObject\ref()                            ; refcounter+1
OutputStreamObject\unref()                          ; delete the object (refcounter-1)

AudioDeviceObject\ref()                             ; refcounter+1
AudioDeviceObject\unref()                           ; delete the object (refCounter-1)
                                                    ;
                                                    ; Note:
                                                    ; It isn't necessary to delete the 
                                                    ; SampleSourceObject and the  
                                                    ; LoopPointSourceObject because 
                                                    ; AUDIERE_OpenSound(foo) takes care of it.
                                                    ; Don't ask me why .... :*|
CloseLibrary(#audiere)
; ExecutableFormat=Windows
; CursorPosition=39
; FirstLine=14
; EOF